#
# spec file for package reuse
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2017 Free Software Foundation Europe e.V.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           reuse
Version:        0.11.1
Release:        bp154.1.22
Summary:        A tool for compliance with the REUSE recommendations
License:        GPL-3.0-or-later AND CC-BY-SA-4.0 AND Apache-2.0 AND CC0-1.0
Group:          Development/Languages/Python
URL:            https://git.fsfe.org/reuse/reuse
Source:         https://files.pythonhosted.org/packages/source/r/reuse/reuse-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  python-rpm-macros
BuildRequires:  python3 >= 3.6
BuildRequires:  python3-Jinja2
BuildRequires:  python3-binaryornot
BuildRequires:  python3-boolean.py
BuildRequires:  python3-debian
BuildRequires:  python3-devel
BuildRequires:  python3-license-expression
BuildRequires:  python3-pytest
BuildRequires:  python3-requests
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
Requires:       python3 >= 3.6
Requires:       python3-Jinja2
Requires:       python3-binaryornot
Requires:       python3-boolean.py
Requires:       python3-debian
Requires:       python3-license-expression
Requires:       python3-requests
Recommends:     git
BuildArch:      noarch

%description
A tool for compliance with the REUSE recommendations.  Essentially,
it is a linter that checks for a project's compliance, and a compiler that
generates a project's bill of materials.

%prep
%setup -q -n reuse-%{version}

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{$python3_sitelib}

%check
PYTHONDONTWRITEBYTECODE=1 LC_ALL=C.UTF-8 LANG=C.UTF-8 PYTHONPATH=%{buildroot}%{python3_sitelib} py.test tests/

%files
%defattr(-,root,root,-)
%doc  README.md CHANGELOG.md
%license LICENSES/*
%{_bindir}/reuse
%{python3_sitelib}/*

%changelog
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.11.1:
  - Always write the output files encoded in UTF-8, explicitly. This is already the
    default on most Unix systems, but it was not on Windows.
  - All symlinks and 0-sized files in projects are now ignored.
  - The licenses CAL-1.0 and CAL-1.0-Combined-Work-Exception contain an SPDX tag
    within themselves. Files that are named after these licenses are now ignored.
  - Fixed a bug where `addheader` wouldn't properly apply the template on
    `.license` files if the `.license` file was non-empty, but did not contain
    valid SPDX tags.
  - Add support for autoconf comment style (listed as m4).
    + Cython (`.pyx`, `.pxd`)
    + Sass and SCSS (`.sass`, `.scss`)
    + XSL (`.xsl`)
    + Mailmap (`.mailmap`)
  - Added `--single-line` and `--multi-line` flags to `addheader`. These flags
    force a certain comment style.
  - Added support for Mercurial 4.3+.
  - A pre-commit hook has been added.
  - When an incorrect SPDX identifier is forwarded to `download` or `init`, the
    tool now suggests what you might have meant.
  - Under the hood, a lot of code that has to do with Git and Mercurial was moved
    into its own module.
  - Fixed a bug with `addheader --explicit-license` that would result in
    `file.license.license` if `file.license` already existed.
  - Fixed a Windows-only bug to do with calling subprocesses.
  - Fixed a rare bug that would trigger when a directory is both ignored and
    contains a `.git` file.
* Thu Jan 23 2020 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to version 0.8.0:
  + Performance improved with multiprocessing
  + New translations added for various different languages.
  + Can no longer lint subdirectories; must specify root with --root.
  + addheader supports many more file types.
  + Deprecated licenses are now recognised.
* Thu Nov 28 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to version 0.7.0:
  + Git submodules are ignored by default. Use --include-submodules
    to include them again.
  + Upstream name changed from fsfe-reuse to reuse.
  + addheader improvements.
* Thu Sep  5 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to version 0.5.0:
  + The tool is now compliant with REUSE v3.0
* Wed Aug 15 2018 carmen@carmenbianca.eu
- Update to version 0.3.3:
  + Files ending in .spdx are no longer considered licenses.
* Tue Aug 14 2018 carmen@carmenbianca.eu
- Update to version 0.3.1:
  + Finding of root directory fixed when using pygit2.
* Wed May 16 2018 carmen@carmenbianca.eu
- Update to version 0.3.0:
  + Bill of materials output is now deterministic.  Entries are
    sorted.
* Tue Apr 17 2018 carmen@carmenbianca.eu
- Update to version 0.2.0:
  + Added translations for Dutch, Esperanto and Spanish.
  + Added new `-only` and `-or-later` SPDX tags for GPL.
  + Based on argparse instead of click.
- Remove xfail-test.patch.
* Tue Dec 19 2017 carmen@carmenbianca.eu
- Added package, version 0.1.1.
- Add xfail-test.patch to ignore a test that fails occasionally.
